@@ -1,6 +1,28 @@
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 
+#[derive(Debug, Serialize, Deserialize)]
+pub struct ScriptInfo {
+    pub path: PathBuf,
+    pub hooks: Vec<Hook>,
+    pub is_daemon: bool,
+}
+#[derive(Clone, Copy, Eq, PartialEq, Hash, Debug, Serialize, Deserialize)]
+pub enum Hook {
+    InputEvent,
+    OutputEvent,
+    SetInputPrompt,
+    SetOutputPrompt,
+    WhileCompiling,
+    AfterCompile,
+}
+
+#[derive(Eq, PartialEq, Debug, Serialize, Deserialize)]
+pub enum Message {
+    Greeting,
+    Hook,
+}
+
 #[derive(Debug, Serialize, Deserialize)]
 pub enum Command {
     AcceptSuggestion,
@@ -35,7 +57,7 @@ pub enum Command {
     Exit,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct GlobalVariables {
     current_working_dir: PathBuf,
     previous_working_dir: PathBuf,
